@@ -1,4 +1,4 @@
-/* $Cambridge: exim/exim-src/src/functions.h,v 1.47 2009/11/16 19:50:37 nm4 Exp $ */
+/* $Cambridge: exim/src/src/functions.h,v 1.52 2010/06/06 22:46:34 pdp Exp $ */
 
 /*************************************************
 *     Exim - an Internet mail transport agent    *
@@ -36,6 +36,9 @@ extern BOOL    tls_smtp_buffered(void);
 extern int     tls_ungetc(int);
 extern int     tls_write(const uschar *, size_t);
 extern void    tls_version_report(FILE *);
+#ifndef USE_GNUTLS
+extern BOOL    tls_openssl_options_parse(uschar *, long *);
+#endif
 #endif
 
 
@@ -69,11 +72,14 @@ extern void    daemon_go(void);
 extern int     dcc_process(uschar **);
 #endif
 
+extern void    debug_logging_activate(uschar *, uschar *);
 extern void    debug_print_argv(uschar **);
 extern void    debug_print_ids(uschar *);
 extern void    debug_print_string(uschar *);
 extern void    debug_print_tree(tree_node *);
 extern void    debug_vprintf(char *, va_list);
+extern void    decode_bits(unsigned int *, unsigned int *,
+                  int, int, uschar *, bit_table *, int, uschar *, int);
 extern address_item *deliver_make_addr(uschar *, BOOL);
 extern int     deliver_message(uschar *, BOOL, BOOL);
 extern void    deliver_msglog(const char *, ...);
@@ -138,6 +144,7 @@ extern int     host_nmtoa(int, int *, int, uschar *, int);
 extern uschar *host_ntoa(int, const void *, uschar *, int *);
 extern int     host_scan_for_local_hosts(host_item *, host_item **, BOOL *);
 
+extern void    invert_address(uschar *, uschar *);
 extern int     ip_bind(int, int, uschar *, int);
 extern int     ip_connect(int, int, uschar *, int, int);
 extern void    ip_keepalive(int, uschar *, BOOL);
@@ -149,6 +156,7 @@ extern void    log_close_all(void);
 
 #ifdef WITH_CONTENT_SCAN
 extern int     malware(uschar **);
+extern int     malware_in_file(uschar *);
 #endif
 extern int     match_address_list(uschar *, BOOL, BOOL, uschar **,
                  unsigned int *, int, int, uschar **);
@@ -294,7 +302,7 @@ extern BOOL    smtp_verify_helo(void);
 extern int     smtp_write_command(smtp_outblock *, BOOL, char *, ...);
 #ifdef WITH_CONTENT_SCAN
 extern int     spam(uschar **);
-extern FILE   *spool_mbox(unsigned long *);
+extern FILE   *spool_mbox(unsigned long *, uschar *);
 #endif
 extern BOOL    spool_move_message(uschar *, uschar *, uschar *, uschar *);
 extern BOOL    spool_open_datafile(uschar *);
